# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from api.v1 import bank_pb2 as api_dot_v1_dot_bank__pb2


class BankServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetBank = channel.unary_unary(
            "/api.v1.BankService/GetBank",
            request_serializer=api_dot_v1_dot_bank__pb2.GetBankRequest.SerializeToString,
            response_deserializer=api_dot_v1_dot_bank__pb2.GetBankResponse.FromString,
            _registered_method=True,
        )
        self.GetMajorBanks = channel.unary_unary(
            "/api.v1.BankService/GetMajorBanks",
            request_serializer=api_dot_v1_dot_bank__pb2.GetMajorBanksRequest.SerializeToString,
            response_deserializer=api_dot_v1_dot_bank__pb2.GetMajorBanksResponse.FromString,
            _registered_method=True,
        )
        self.SearchBanks = channel.unary_unary(
            "/api.v1.BankService/SearchBanks",
            request_serializer=api_dot_v1_dot_bank__pb2.SearchBanksRequest.SerializeToString,
            response_deserializer=api_dot_v1_dot_bank__pb2.SearchBanksResponse.FromString,
            _registered_method=True,
        )
        self.GetBranch = channel.unary_unary(
            "/api.v1.BankService/GetBranch",
            request_serializer=api_dot_v1_dot_bank__pb2.GetBranchRequest.SerializeToString,
            response_deserializer=api_dot_v1_dot_bank__pb2.GetBranchResponse.FromString,
            _registered_method=True,
        )
        self.GetBranches = channel.unary_unary(
            "/api.v1.BankService/GetBranches",
            request_serializer=api_dot_v1_dot_bank__pb2.GetBranchesRequest.SerializeToString,
            response_deserializer=api_dot_v1_dot_bank__pb2.GetBranchesResponse.FromString,
            _registered_method=True,
        )
        self.SearchBranches = channel.unary_unary(
            "/api.v1.BankService/SearchBranches",
            request_serializer=api_dot_v1_dot_bank__pb2.SearchBranchesRequest.SerializeToString,
            response_deserializer=api_dot_v1_dot_bank__pb2.SearchBranchesResponse.FromString,
            _registered_method=True,
        )


class BankServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetBank(self, request, context):
        """GetBank returns a bank by the bank code."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetMajorBanks(self, request, context):
        """GetMajorBanks returns a list of major banks to render Mizuho, SMBC, and MUFG in Core UI."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SearchBanks(self, request, context):
        """SearchBanks returns a list of banks that match the query."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetBranch(self, request, context):
        """GetBranch returns a branch by the bank code and branch code."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetBranches(self, request, context):
        """GetBranches returns a list of branches by the bank code."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SearchBranches(self, request, context):
        """SearchBranches returns a list of branches that match the query."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_BankServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "GetBank": grpc.unary_unary_rpc_method_handler(
            servicer.GetBank,
            request_deserializer=api_dot_v1_dot_bank__pb2.GetBankRequest.FromString,
            response_serializer=api_dot_v1_dot_bank__pb2.GetBankResponse.SerializeToString,
        ),
        "GetMajorBanks": grpc.unary_unary_rpc_method_handler(
            servicer.GetMajorBanks,
            request_deserializer=api_dot_v1_dot_bank__pb2.GetMajorBanksRequest.FromString,
            response_serializer=api_dot_v1_dot_bank__pb2.GetMajorBanksResponse.SerializeToString,
        ),
        "SearchBanks": grpc.unary_unary_rpc_method_handler(
            servicer.SearchBanks,
            request_deserializer=api_dot_v1_dot_bank__pb2.SearchBanksRequest.FromString,
            response_serializer=api_dot_v1_dot_bank__pb2.SearchBanksResponse.SerializeToString,
        ),
        "GetBranch": grpc.unary_unary_rpc_method_handler(
            servicer.GetBranch,
            request_deserializer=api_dot_v1_dot_bank__pb2.GetBranchRequest.FromString,
            response_serializer=api_dot_v1_dot_bank__pb2.GetBranchResponse.SerializeToString,
        ),
        "GetBranches": grpc.unary_unary_rpc_method_handler(
            servicer.GetBranches,
            request_deserializer=api_dot_v1_dot_bank__pb2.GetBranchesRequest.FromString,
            response_serializer=api_dot_v1_dot_bank__pb2.GetBranchesResponse.SerializeToString,
        ),
        "SearchBranches": grpc.unary_unary_rpc_method_handler(
            servicer.SearchBranches,
            request_deserializer=api_dot_v1_dot_bank__pb2.SearchBranchesRequest.FromString,
            response_serializer=api_dot_v1_dot_bank__pb2.SearchBranchesResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "api.v1.BankService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers("api.v1.BankService", rpc_method_handlers)


# This class is part of an EXPERIMENTAL API.
class BankService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetBank(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v1.BankService/GetBank",
            api_dot_v1_dot_bank__pb2.GetBankRequest.SerializeToString,
            api_dot_v1_dot_bank__pb2.GetBankResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetMajorBanks(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v1.BankService/GetMajorBanks",
            api_dot_v1_dot_bank__pb2.GetMajorBanksRequest.SerializeToString,
            api_dot_v1_dot_bank__pb2.GetMajorBanksResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def SearchBanks(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v1.BankService/SearchBanks",
            api_dot_v1_dot_bank__pb2.SearchBanksRequest.SerializeToString,
            api_dot_v1_dot_bank__pb2.SearchBanksResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetBranch(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v1.BankService/GetBranch",
            api_dot_v1_dot_bank__pb2.GetBranchRequest.SerializeToString,
            api_dot_v1_dot_bank__pb2.GetBranchResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetBranches(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v1.BankService/GetBranches",
            api_dot_v1_dot_bank__pb2.GetBranchesRequest.SerializeToString,
            api_dot_v1_dot_bank__pb2.GetBranchesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def SearchBranches(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v1.BankService/SearchBranches",
            api_dot_v1_dot_bank__pb2.SearchBranchesRequest.SerializeToString,
            api_dot_v1_dot_bank__pb2.SearchBranchesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )
