# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: api/v1/bank.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 30, 2, "", "api/v1/bank.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from api.v1 import common_pb2 as api_dot_v1_dot_common__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x11\x61pi/v1/bank.proto\x12\x06\x61pi.v1\x1a\x13\x61pi/v1/common.proto\x1a\x1b\x62uf/validate/validate.proto"7\n\x0eGetBankRequest\x12%\n\tbank_code\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\x98\x01\x04R\x08\x62\x61nkCode"3\n\x0fGetBankResponse\x12 \n\x04\x62\x61nk\x18\x01 \x01(\x0b\x32\x0c.api.v1.BankR\x04\x62\x61nk"\x16\n\x14GetMajorBanksRequest"\x81\x01\n\x15GetMajorBanksResponse\x12$\n\x06mizuho\x18\x01 \x01(\x0b\x32\x0c.api.v1.BankR\x06mizuho\x12 \n\x04mufg\x18\x02 \x01(\x0b\x32\x0c.api.v1.BankR\x04mufg\x12 \n\x04smbc\x18\x03 \x01(\x0b\x32\x0c.api.v1.BankR\x04smbc"5\n\x12SearchBanksRequest\x12\x1f\n\x05query\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18\x32R\x05query"9\n\x13SearchBanksResponse\x12"\n\x05\x62\x61nks\x18\x01 \x03(\x0b\x32\x0c.api.v1.BankR\x05\x62\x61nks"d\n\x10GetBranchRequest\x12%\n\tbank_code\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\x98\x01\x04R\x08\x62\x61nkCode\x12)\n\x0b\x62ranch_code\x18\x02 \x01(\tB\x08\xbaH\x05r\x03\x98\x01\x03R\nbranchCode"?\n\x11GetBranchResponse\x12*\n\x06\x62ranch\x18\x01 \x01(\x0b\x32\x12.api.v1.BankBranchR\x06\x62ranch";\n\x12GetBranchesRequest\x12%\n\tbank_code\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\x98\x01\x04R\x08\x62\x61nkCode"E\n\x13GetBranchesResponse\x12.\n\x08\x62ranches\x18\x01 \x03(\x0b\x32\x12.api.v1.BankBranchR\x08\x62ranches"_\n\x15SearchBranchesRequest\x12%\n\tbank_code\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\x98\x01\x04R\x08\x62\x61nkCode\x12\x1f\n\x05query\x18\x02 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18\x32R\x05query"H\n\x16SearchBranchesResponse\x12.\n\x08\x62ranches\x18\x01 \x03(\x0b\x32\x12.api.v1.BankBranchR\x08\x62ranches2\xc6\x03\n\x0b\x42\x61nkService\x12<\n\x07GetBank\x12\x16.api.v1.GetBankRequest\x1a\x17.api.v1.GetBankResponse"\x00\x12N\n\rGetMajorBanks\x12\x1c.api.v1.GetMajorBanksRequest\x1a\x1d.api.v1.GetMajorBanksResponse"\x00\x12H\n\x0bSearchBanks\x12\x1a.api.v1.SearchBanksRequest\x1a\x1b.api.v1.SearchBanksResponse"\x00\x12\x42\n\tGetBranch\x12\x18.api.v1.GetBranchRequest\x1a\x19.api.v1.GetBranchResponse"\x00\x12H\n\x0bGetBranches\x12\x1a.api.v1.GetBranchesRequest\x1a\x1b.api.v1.GetBranchesResponse"\x00\x12Q\n\x0eSearchBranches\x12\x1d.api.v1.SearchBranchesRequest\x1a\x1e.api.v1.SearchBranchesResponse"\x00\x42m\n\ncom.api.v1B\tBankProtoP\x01Z\x1b\x61pi/proto/gen/api/v1;api_v1\xa2\x02\x03\x41XX\xaa\x02\x06\x41pi.V1\xca\x02\x06\x41pi\\V1\xe2\x02\x12\x41pi\\V1\\GPBMetadata\xea\x02\x07\x41pi::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "api.v1.bank_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = (
        b"\n\ncom.api.v1B\tBankProtoP\001Z\033api/proto/gen/api/v1;api_v1\242\002\003AXX\252\002\006Api.V1\312\002\006Api\\V1\342\002\022Api\\V1\\GPBMetadata\352\002\007Api::V1"
    )
    _globals["_GETBANKREQUEST"].fields_by_name["bank_code"]._loaded_options = None
    _globals["_GETBANKREQUEST"].fields_by_name[
        "bank_code"
    ]._serialized_options = b"\272H\005r\003\230\001\004"
    _globals["_SEARCHBANKSREQUEST"].fields_by_name["query"]._loaded_options = None
    _globals["_SEARCHBANKSREQUEST"].fields_by_name[
        "query"
    ]._serialized_options = b"\272H\006r\004\020\001\0302"
    _globals["_GETBRANCHREQUEST"].fields_by_name["bank_code"]._loaded_options = None
    _globals["_GETBRANCHREQUEST"].fields_by_name[
        "bank_code"
    ]._serialized_options = b"\272H\005r\003\230\001\004"
    _globals["_GETBRANCHREQUEST"].fields_by_name["branch_code"]._loaded_options = None
    _globals["_GETBRANCHREQUEST"].fields_by_name[
        "branch_code"
    ]._serialized_options = b"\272H\005r\003\230\001\003"
    _globals["_GETBRANCHESREQUEST"].fields_by_name["bank_code"]._loaded_options = None
    _globals["_GETBRANCHESREQUEST"].fields_by_name[
        "bank_code"
    ]._serialized_options = b"\272H\005r\003\230\001\004"
    _globals["_SEARCHBRANCHESREQUEST"].fields_by_name[
        "bank_code"
    ]._loaded_options = None
    _globals["_SEARCHBRANCHESREQUEST"].fields_by_name[
        "bank_code"
    ]._serialized_options = b"\272H\005r\003\230\001\004"
    _globals["_SEARCHBRANCHESREQUEST"].fields_by_name["query"]._loaded_options = None
    _globals["_SEARCHBRANCHESREQUEST"].fields_by_name[
        "query"
    ]._serialized_options = b"\272H\006r\004\020\001\0302"
    _globals["_GETBANKREQUEST"]._serialized_start = 79
    _globals["_GETBANKREQUEST"]._serialized_end = 134
    _globals["_GETBANKRESPONSE"]._serialized_start = 136
    _globals["_GETBANKRESPONSE"]._serialized_end = 187
    _globals["_GETMAJORBANKSREQUEST"]._serialized_start = 189
    _globals["_GETMAJORBANKSREQUEST"]._serialized_end = 211
    _globals["_GETMAJORBANKSRESPONSE"]._serialized_start = 214
    _globals["_GETMAJORBANKSRESPONSE"]._serialized_end = 343
    _globals["_SEARCHBANKSREQUEST"]._serialized_start = 345
    _globals["_SEARCHBANKSREQUEST"]._serialized_end = 398
    _globals["_SEARCHBANKSRESPONSE"]._serialized_start = 400
    _globals["_SEARCHBANKSRESPONSE"]._serialized_end = 457
    _globals["_GETBRANCHREQUEST"]._serialized_start = 459
    _globals["_GETBRANCHREQUEST"]._serialized_end = 559
    _globals["_GETBRANCHRESPONSE"]._serialized_start = 561
    _globals["_GETBRANCHRESPONSE"]._serialized_end = 624
    _globals["_GETBRANCHESREQUEST"]._serialized_start = 626
    _globals["_GETBRANCHESREQUEST"]._serialized_end = 685
    _globals["_GETBRANCHESRESPONSE"]._serialized_start = 687
    _globals["_GETBRANCHESRESPONSE"]._serialized_end = 756
    _globals["_SEARCHBRANCHESREQUEST"]._serialized_start = 758
    _globals["_SEARCHBRANCHESREQUEST"]._serialized_end = 853
    _globals["_SEARCHBRANCHESRESPONSE"]._serialized_start = 855
    _globals["_SEARCHBRANCHESRESPONSE"]._serialized_end = 927
    _globals["_BANKSERVICE"]._serialized_start = 930
    _globals["_BANKSERVICE"]._serialized_end = 1384
# @@protoc_insertion_point(module_scope)
