# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: api/v1/healthcheck.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 30, 2, "", "api/v1/healthcheck.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from protoc_gen_openapiv2.options import (
    annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2,
)


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x18\x61pi/v1/healthcheck.proto\x12\x06\x61pi.v1\x1a\x1cgoogle/api/annotations.proto\x1a.protoc-gen-openapiv2/options/annotations.proto"\r\n\x0bPingRequest"\x1e\n\x0cPingResponse\x12\x0e\n\x02ok\x18\x01 \x01(\x08R\x02ok2\xc3\x01\n\x12HealthcheckService\x12\xac\x01\n\x04Ping\x12\x13.api.v1.PingRequest\x1a\x14.api.v1.PingResponse"y\x92\x41_\n\x0bhealthcheck\x12$Ping Jamm server to check connection\x1a$Ping Jamm server to check connection*\x04ping\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/healthcheckBt\n\ncom.api.v1B\x10HealthcheckProtoP\x01Z\x1b\x61pi/proto/gen/api/v1;api_v1\xa2\x02\x03\x41XX\xaa\x02\x06\x41pi.V1\xca\x02\x06\x41pi\\V1\xe2\x02\x12\x41pi\\V1\\GPBMetadata\xea\x02\x07\x41pi::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "api.v1.healthcheck_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = (
        b"\n\ncom.api.v1B\020HealthcheckProtoP\001Z\033api/proto/gen/api/v1;api_v1\242\002\003AXX\252\002\006Api.V1\312\002\006Api\\V1\342\002\022Api\\V1\\GPBMetadata\352\002\007Api::V1"
    )
    _globals["_HEALTHCHECKSERVICE"].methods_by_name["Ping"]._loaded_options = None
    _globals["_HEALTHCHECKSERVICE"].methods_by_name[
        "Ping"
    ]._serialized_options = b"\222A_\n\013healthcheck\022$Ping Jamm server to check connection\032$Ping Jamm server to check connection*\004ping\202\323\344\223\002\021\022\017/v1/healthcheck"
    _globals["_PINGREQUEST"]._serialized_start = 114
    _globals["_PINGREQUEST"]._serialized_end = 127
    _globals["_PINGRESPONSE"]._serialized_start = 129
    _globals["_PINGRESPONSE"]._serialized_end = 159
    _globals["_HEALTHCHECKSERVICE"]._serialized_start = 162
    _globals["_HEALTHCHECKSERVICE"]._serialized_end = 357
# @@protoc_insertion_point(module_scope)
