# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: api/v1/openapi.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 30, 2, "", "api/v1/openapi.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protoc_gen_openapiv2.options import (
    annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2,
)


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n\x14\x61pi/v1/openapi.proto\x12\x06\x61pi.v1\x1a.protoc-gen-openapiv2/options/annotations.protoB\xc8\x01\n\ncom.api.v1B\x0cOpenapiProtoP\x01Z\x1b\x61pi/proto/gen/api/v1;api_v1\xa2\x02\x03\x41XX\xaa\x02\x06\x41pi.V1\xca\x02\x06\x41pi\\V1\xe2\x02\x12\x41pi\\V1\\GPBMetadata\xea\x02\x07\x41pi::V1\x92\x41U\x12\x0f\n\x08Jamm API2\x03\x31.0*\x01\x02\x32\x10\x61pplication/json:\x10\x61pplication/jsonr\x1b\n\x04Jamm\x12\x13https://jamm-pay.jpb\x06proto3"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "api.v1.openapi_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = (
        b"\n\ncom.api.v1B\014OpenapiProtoP\001Z\033api/proto/gen/api/v1;api_v1\242\002\003AXX\252\002\006Api.V1\312\002\006Api\\V1\342\002\022Api\\V1\\GPBMetadata\352\002\007Api::V1\222AU\022\017\n\010Jamm API2\0031.0*\001\0022\020application/json:\020application/jsonr\033\n\004Jamm\022\023https://jamm-pay.jp"
    )
# @@protoc_insertion_point(module_scope)
