# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: api/v1/customer.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 30, 2, "", "api/v1/customer.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from api.v1 import common_pb2 as api_dot_v1_dot_common__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from protoc_gen_openapiv2.options import (
    annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2,
)


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x15\x61pi/v1/customer.proto\x12\x06\x61pi.v1\x1a\x13\x61pi/v1/common.proto\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a.protoc-gen-openapiv2/options/annotations.proto"<\n\x15\x43reateCustomerRequest\x12#\n\x05\x62uyer\x18\x01 \x01(\x0b\x32\r.api.v1.BuyerR\x05\x62uyer"N\n\x16\x43reateCustomerResponse\x12\x34\n\x08\x63ustomer\x18\x01 \x01(\x0b\x32\x18.api.v1.MerchantCustomerR\x08\x63ustomer"0\n\x12GetCustomerRequest\x12\x1a\n\x08\x63ustomer\x18\x01 \x01(\tR\x08\x63ustomer"C\n\x13GetCustomerResponse\x12,\n\x08\x63ustomer\x18\x01 \x01(\x0b\x32\x10.api.v1.CustomerR\x08\x63ustomer"\x83\x06\n\x15UpdateCustomerRequest\x12+\n\x08\x63ustomer\x18\x01 \x01(\tB\x0f\xbaH\x0cr\n2\x08^cus-.*$R\x08\x63ustomer\x12U\n\x05\x65mail\x18\x02 \x01(\tB:\xbaH7\xba\x01\x34\n\x0bvalid_email\x12\x15must be a valid email\x1a\x0ethis.isEmail()H\x00R\x05\x65mail\x88\x01\x01\x12 \n\tforce_kyc\x18\x03 \x01(\x08H\x01R\x08\x66orceKyc\x88\x01\x01\x12"\n\x04name\x18\x04 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18\x32H\x02R\x04name\x88\x01\x01\x12<\n\x12katakana_last_name\x18\x0b \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18\x32H\x03R\x10katakanaLastName\x88\x01\x01\x12>\n\x13katakana_first_name\x18\x0c \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18\x32H\x04R\x11katakanaFirstName\x88\x01\x01\x12(\n\x07\x61\x64\x64ress\x18\r \x01(\tB\t\xbaH\x06r\x04\x10\x05\x18\x64H\x05R\x07\x61\x64\x64ress\x88\x01\x01\x12\x41\n\nbirth_date\x18\x14 \x01(\tB\x1d\xbaH\x1ar\x18\x32\x16^(\\d{4}-\\d{2}-\\d{2})?$H\x06R\tbirthDate\x88\x01\x01\x12\x39\n\x06gender\x18\x15 \x01(\tB\x1c\xbaH\x19r\x17R\x06\x66\x65maleR\x04maleR\x07unknownH\x07R\x06gender\x88\x01\x01\x12G\n\x08metadata\x18\x1e \x03(\x0b\x32+.api.v1.UpdateCustomerRequest.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x08\n\x06_emailB\x0c\n\n_force_kycB\x07\n\x05_nameB\x15\n\x13_katakana_last_nameB\x16\n\x14_katakana_first_nameB\n\n\x08_addressB\r\n\x0b_birth_dateB\t\n\x07_gender"N\n\x16UpdateCustomerResponse\x12\x34\n\x08\x63ustomer\x18\x01 \x01(\x0b\x32\x18.api.v1.MerchantCustomerR\x08\x63ustomer"D\n\x15\x44\x65leteCustomerRequest\x12+\n\x08\x63ustomer\x18\x01 \x01(\tB\x0f\xbaH\x0cr\n2\x08^cus-.*$R\x08\x63ustomer"4\n\x16\x44\x65leteCustomerResponse\x12\x1a\n\x08\x61\x63\x63\x65pted\x18\x01 \x01(\x08R\x08\x61\x63\x63\x65pted"A\n\x12GetContractRequest\x12+\n\x08\x63ustomer\x18\x01 \x01(\tB\x0f\xbaH\x0cr\n2\x08^cus-.*$R\x08\x63ustomer"y\n\x13GetContractResponse\x12\x34\n\x08\x63ustomer\x18\x01 \x01(\x0b\x32\x18.api.v1.MerchantCustomerR\x08\x63ustomer\x12,\n\x08\x63ontract\x18\x02 \x01(\x0b\x32\x10.api.v1.ContractR\x08\x63ontract2\xd4\x08\n\x0f\x43ustomerService\x12\xca\x01\n\x0e\x43reateCustomer\x12\x1d.api.v1.CreateCustomerRequest\x1a\x1e.api.v1.CreateCustomerResponse"y\x92\x41^\n\x08\x63ustomer\x12\x0f\x43reate customer\x1a\x39Intended for pre-registering merchant customer into Jamm.*\x06\x63reate\x82\xd3\xe4\x93\x02\x12"\r/v1/customers:\x01*\x12\xe4\x01\n\x0bGetCustomer\x12\x1a.api.v1.GetCustomerRequest\x1a\x1b.api.v1.GetCustomerResponse"\x9b\x01\x92\x41x\n\x08\x63ustomer\x12\x0cGet customer\x1aYRetrieve a merchant customer from Jamm. The merchant customer must be registered in Jamm.*\x03get\x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/customers/{customer}\x12\xf7\x01\n\x0eUpdateCustomer\x12\x1d.api.v1.UpdateCustomerRequest\x1a\x1e.api.v1.UpdateCustomerResponse"\xa5\x01\x92\x41\x7f\n\x08\x63ustomer\x12\x0fUpdate customer\x1aZUpdate customer metadata when they updated their information in merchant e-commerce store.*\x06update\x82\xd3\xe4\x93\x02\x1d\x1a\x18/v1/customers/{customer}:\x01*\x12\xb3\x01\n\x0e\x44\x65leteCustomer\x12\x1d.api.v1.DeleteCustomerRequest\x1a\x1e.api.v1.DeleteCustomerResponse"b\x92\x41?\n\x08\x63ustomer\x12\x0f\x44\x65lete customer\x1a\x1a\x44\x65lete customer from Jamm.*\x06\x64\x65lete\x82\xd3\xe4\x93\x02\x1a*\x18/v1/customers/{customer}\x12\xdc\x01\n\x0bGetContract\x12\x1a.api.v1.GetContractRequest\x1a\x1b.api.v1.GetContractResponse"\x93\x01\x92\x41g\n\x08\x63ustomer\x12&Get a contract belongs to the customer\x1a&Get a contract belongs to the customer*\x0bgetContract\x82\xd3\xe4\x93\x02#\x12!/v1/customers/{customer}/contractBq\n\ncom.api.v1B\rCustomerProtoP\x01Z\x1b\x61pi/proto/gen/api/v1;api_v1\xa2\x02\x03\x41XX\xaa\x02\x06\x41pi.V1\xca\x02\x06\x41pi\\V1\xe2\x02\x12\x41pi\\V1\\GPBMetadata\xea\x02\x07\x41pi::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "api.v1.customer_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = (
        b"\n\ncom.api.v1B\rCustomerProtoP\001Z\033api/proto/gen/api/v1;api_v1\242\002\003AXX\252\002\006Api.V1\312\002\006Api\\V1\342\002\022Api\\V1\\GPBMetadata\352\002\007Api::V1"
    )
    _globals["_UPDATECUSTOMERREQUEST_METADATAENTRY"]._loaded_options = None
    _globals["_UPDATECUSTOMERREQUEST_METADATAENTRY"]._serialized_options = b"8\001"
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name["customer"]._loaded_options = None
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name[
        "customer"
    ]._serialized_options = b"\272H\014r\n2\010^cus-.*$"
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name["email"]._loaded_options = None
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name[
        "email"
    ]._serialized_options = b"\272H7\272\0014\n\013valid_email\022\025must be a valid email\032\016this.isEmail()"
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name["name"]._loaded_options = None
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name[
        "name"
    ]._serialized_options = b"\272H\006r\004\020\001\0302"
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name[
        "katakana_last_name"
    ]._loaded_options = None
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name[
        "katakana_last_name"
    ]._serialized_options = b"\272H\006r\004\020\001\0302"
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name[
        "katakana_first_name"
    ]._loaded_options = None
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name[
        "katakana_first_name"
    ]._serialized_options = b"\272H\006r\004\020\001\0302"
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name["address"]._loaded_options = None
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name[
        "address"
    ]._serialized_options = b"\272H\006r\004\020\005\030d"
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name[
        "birth_date"
    ]._loaded_options = None
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name[
        "birth_date"
    ]._serialized_options = b"\272H\032r\0302\026^(\\d{4}-\\d{2}-\\d{2})?$"
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name["gender"]._loaded_options = None
    _globals["_UPDATECUSTOMERREQUEST"].fields_by_name[
        "gender"
    ]._serialized_options = b"\272H\031r\027R\006femaleR\004maleR\007unknown"
    _globals["_DELETECUSTOMERREQUEST"].fields_by_name["customer"]._loaded_options = None
    _globals["_DELETECUSTOMERREQUEST"].fields_by_name[
        "customer"
    ]._serialized_options = b"\272H\014r\n2\010^cus-.*$"
    _globals["_GETCONTRACTREQUEST"].fields_by_name["customer"]._loaded_options = None
    _globals["_GETCONTRACTREQUEST"].fields_by_name[
        "customer"
    ]._serialized_options = b"\272H\014r\n2\010^cus-.*$"
    _globals["_CUSTOMERSERVICE"].methods_by_name[
        "CreateCustomer"
    ]._loaded_options = None
    _globals["_CUSTOMERSERVICE"].methods_by_name[
        "CreateCustomer"
    ]._serialized_options = b'\222A^\n\010customer\022\017Create customer\0329Intended for pre-registering merchant customer into Jamm.*\006create\202\323\344\223\002\022"\r/v1/customers:\001*'
    _globals["_CUSTOMERSERVICE"].methods_by_name["GetCustomer"]._loaded_options = None
    _globals["_CUSTOMERSERVICE"].methods_by_name[
        "GetCustomer"
    ]._serialized_options = b"\222Ax\n\010customer\022\014Get customer\032YRetrieve a merchant customer from Jamm. The merchant customer must be registered in Jamm.*\003get\202\323\344\223\002\032\022\030/v1/customers/{customer}"
    _globals["_CUSTOMERSERVICE"].methods_by_name[
        "UpdateCustomer"
    ]._loaded_options = None
    _globals["_CUSTOMERSERVICE"].methods_by_name[
        "UpdateCustomer"
    ]._serialized_options = b"\222A\177\n\010customer\022\017Update customer\032ZUpdate customer metadata when they updated their information in merchant e-commerce store.*\006update\202\323\344\223\002\035\032\030/v1/customers/{customer}:\001*"
    _globals["_CUSTOMERSERVICE"].methods_by_name[
        "DeleteCustomer"
    ]._loaded_options = None
    _globals["_CUSTOMERSERVICE"].methods_by_name[
        "DeleteCustomer"
    ]._serialized_options = b"\222A?\n\010customer\022\017Delete customer\032\032Delete customer from Jamm.*\006delete\202\323\344\223\002\032*\030/v1/customers/{customer}"
    _globals["_CUSTOMERSERVICE"].methods_by_name["GetContract"]._loaded_options = None
    _globals["_CUSTOMERSERVICE"].methods_by_name[
        "GetContract"
    ]._serialized_options = b"\222Ag\n\010customer\022&Get a contract belongs to the customer\032&Get a contract belongs to the customer*\013getContract\202\323\344\223\002#\022!/v1/customers/{customer}/contract"
    _globals["_CREATECUSTOMERREQUEST"]._serialized_start = 161
    _globals["_CREATECUSTOMERREQUEST"]._serialized_end = 221
    _globals["_CREATECUSTOMERRESPONSE"]._serialized_start = 223
    _globals["_CREATECUSTOMERRESPONSE"]._serialized_end = 301
    _globals["_GETCUSTOMERREQUEST"]._serialized_start = 303
    _globals["_GETCUSTOMERREQUEST"]._serialized_end = 351
    _globals["_GETCUSTOMERRESPONSE"]._serialized_start = 353
    _globals["_GETCUSTOMERRESPONSE"]._serialized_end = 420
    _globals["_UPDATECUSTOMERREQUEST"]._serialized_start = 423
    _globals["_UPDATECUSTOMERREQUEST"]._serialized_end = 1194
    _globals["_UPDATECUSTOMERREQUEST_METADATAENTRY"]._serialized_start = 1017
    _globals["_UPDATECUSTOMERREQUEST_METADATAENTRY"]._serialized_end = 1076
    _globals["_UPDATECUSTOMERRESPONSE"]._serialized_start = 1196
    _globals["_UPDATECUSTOMERRESPONSE"]._serialized_end = 1274
    _globals["_DELETECUSTOMERREQUEST"]._serialized_start = 1276
    _globals["_DELETECUSTOMERREQUEST"]._serialized_end = 1344
    _globals["_DELETECUSTOMERRESPONSE"]._serialized_start = 1346
    _globals["_DELETECUSTOMERRESPONSE"]._serialized_end = 1398
    _globals["_GETCONTRACTREQUEST"]._serialized_start = 1400
    _globals["_GETCONTRACTREQUEST"]._serialized_end = 1465
    _globals["_GETCONTRACTRESPONSE"]._serialized_start = 1467
    _globals["_GETCONTRACTRESPONSE"]._serialized_end = 1588
    _globals["_CUSTOMERSERVICE"]._serialized_start = 1591
    _globals["_CUSTOMERSERVICE"]._serialized_end = 2699
# @@protoc_insertion_point(module_scope)
