from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class ErrorType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ERROR_TYPE_UNSPECIFIED: _ClassVar[ErrorType]
    ERROR_TYPE_AUTH_FAILED: _ClassVar[ErrorType]
    ERROR_TYPE_AUTH_REJECTED: _ClassVar[ErrorType]
    ERROR_TYPE_ACCOUNT_CREATION_FAILED: _ClassVar[ErrorType]
    ERROR_TYPE_ACCOUNT_MODIFICATION_FAILED: _ClassVar[ErrorType]
    ERROR_TYPE_ACCOUNT_DELETION_FAILED: _ClassVar[ErrorType]
    ERROR_TYPE_ACCOUNT_BANK_REGISTRATION_FAILED: _ClassVar[ErrorType]
    ERROR_TYPE_KYC_REJECTED: _ClassVar[ErrorType]
    ERROR_TYPE_NOTIFICATION_WEBHOOK_FAILED: _ClassVar[ErrorType]
    ERROR_TYPE_NOTIFICATION_EMAIL_FAILED: _ClassVar[ErrorType]
    ERROR_TYPE_NOTIFICATION_SMS_FAILED: _ClassVar[ErrorType]
    ERROR_TYPE_PAYMENT_GATEWAY_UNAVAILABLE: _ClassVar[ErrorType]
    ERROR_TYPE_PAYMENT_GATEWAY_FAILED: _ClassVar[ErrorType]
    ERROR_TYPE_PAYMENT_VALIDATION_FAILED: _ClassVar[ErrorType]
    ERROR_TYPE_PAYMENT_CHARGE_FAILED: _ClassVar[ErrorType]
    ERROR_TYPE_PAYMENT_CHARGE_REJECTED: _ClassVar[ErrorType]
    ERROR_TYPE_PAYMENT_CHARGE_OVER_LIMIT: _ClassVar[ErrorType]
    ERROR_TYPE_PAYMENT_CHARGE_SUBSCRIPTION_EXPIRED: _ClassVar[ErrorType]
    ERROR_TYPE_PAYMENT_LINK_EXPIRED: _ClassVar[ErrorType]

ERROR_TYPE_UNSPECIFIED: ErrorType
ERROR_TYPE_AUTH_FAILED: ErrorType
ERROR_TYPE_AUTH_REJECTED: ErrorType
ERROR_TYPE_ACCOUNT_CREATION_FAILED: ErrorType
ERROR_TYPE_ACCOUNT_MODIFICATION_FAILED: ErrorType
ERROR_TYPE_ACCOUNT_DELETION_FAILED: ErrorType
ERROR_TYPE_ACCOUNT_BANK_REGISTRATION_FAILED: ErrorType
ERROR_TYPE_KYC_REJECTED: ErrorType
ERROR_TYPE_NOTIFICATION_WEBHOOK_FAILED: ErrorType
ERROR_TYPE_NOTIFICATION_EMAIL_FAILED: ErrorType
ERROR_TYPE_NOTIFICATION_SMS_FAILED: ErrorType
ERROR_TYPE_PAYMENT_GATEWAY_UNAVAILABLE: ErrorType
ERROR_TYPE_PAYMENT_GATEWAY_FAILED: ErrorType
ERROR_TYPE_PAYMENT_VALIDATION_FAILED: ErrorType
ERROR_TYPE_PAYMENT_CHARGE_FAILED: ErrorType
ERROR_TYPE_PAYMENT_CHARGE_REJECTED: ErrorType
ERROR_TYPE_PAYMENT_CHARGE_OVER_LIMIT: ErrorType
ERROR_TYPE_PAYMENT_CHARGE_SUBSCRIPTION_EXPIRED: ErrorType
ERROR_TYPE_PAYMENT_LINK_EXPIRED: ErrorType
