# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: common/v1/webapp.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 30, 2, "", "common/v1/webapp.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16\x63ommon/v1/webapp.proto\x12\tcommon.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\x9d\x06\n\x04\x42\x61nk\x12\x12\n\x04\x63ode\x18\x01 \x01(\tR\x04\x63ode\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12#\n\rname_katakana\x18\x03 \x01(\tR\x0cnameKatakana\x12#\n\rname_hiragana\x18\x04 \x01(\tR\x0cnameHiragana\x12#\n\rname_alphabet\x18\x05 \x01(\tR\x0cnameAlphabet\x12-\n\x06\x61ssets\x18\x0b \x01(\x0b\x32\x15.common.v1.BankAssetsR\x06\x61ssets\x12*\n\x05quota\x18\x14 \x01(\x0b\x32\x14.common.v1.BankQuotaR\x05quota\x12#\n\ropening_hours\x18\x1e \x01(\tR\x0copeningHours\x12o\n\x1e\x62\x61nkpay_scheduled_maintenances\x18( \x03(\x0b\x32).common.v1.BankScheduledMaintenancePeriodR\x1c\x62\x61nkpayScheduledMaintenances\x12i\n\x1b\x62\x61nk_scheduled_maintenances\x18) \x03(\x0b\x32).common.v1.BankScheduledMaintenancePeriodR\x19\x62\x61nkScheduledMaintenances\x12y\n#registration_scheduled_maintenances\x18* \x03(\x0b\x32).common.v1.BankScheduledMaintenancePeriodR!registrationScheduledMaintenances\x12+\n\x11\x62\x61nkpay_available\x18\x32 \x01(\x08R\x10\x62\x61nkpayAvailable\x12%\n\x0e\x62\x61nk_available\x18\x33 \x01(\x08R\rbankAvailable\x12\x35\n\x16registration_available\x18\x34 \x01(\x08R\x15registrationAvailable\x12\x1c\n\toperating\x18\x63 \x01(\x08R\toperating"\x83\x06\n\tBankQuota\x12X\n*offline_purchase_limit_per_charge_with_kyc\x18\x01 \x01(\x05R$offlinePurchaseLimitPerChargeWithKyc\x12^\n-offline_purchase_limit_per_charge_without_kyc\x18\x02 \x01(\x05R\'offlinePurchaseLimitPerChargeWithoutKyc\x12R\n\'offline_purchase_limit_per_day_with_kyc\x18\n \x01(\x05R!offlinePurchaseLimitPerDayWithKyc\x12X\n*offline_purchase_limit_per_day_without_kyc\x18\x0b \x01(\x05R$offlinePurchaseLimitPerDayWithoutKyc\x12\x62\n/subscription_purchase_limit_per_charge_with_kyc\x18\x14 \x01(\x05R)subscriptionPurchaseLimitPerChargeWithKyc\x12h\n2subscription_purchase_limit_per_charge_without_kyc\x18\x15 \x01(\x05R,subscriptionPurchaseLimitPerChargeWithoutKyc\x12\\\n,subscription_purchase_limit_per_day_with_kyc\x18\x1e \x01(\x05R&subscriptionPurchaseLimitPerDayWithKyc\x12\x62\n/subscription_purchase_limit_per_day_without_kyc\x18\x1f \x01(\x05R)subscriptionPurchaseLimitPerDayWithoutKyc"\xbd\x01\n\x1e\x42\x61nkScheduledMaintenancePeriod\x12\x1b\n\tbank_code\x18\x01 \x01(\tR\x08\x62\x61nkCode\x12 \n\x0cstart_at_jst\x18\x02 \x01(\tR\nstartAtJst\x12\x1c\n\nend_at_jst\x18\x03 \x01(\tR\x08\x65ndAtJst\x12 \n\x0cstart_at_utc\x18\x04 \x01(\tR\nstartAtUtc\x12\x1c\n\nend_at_utc\x18\x05 \x01(\tR\x08\x65ndAtUtc"\xcd\x01\n\nBankBranch\x12\x1b\n\tbank_code\x18\x01 \x01(\tR\x08\x62\x61nkCode\x12\x1f\n\x0b\x62ranch_code\x18\x02 \x01(\tR\nbranchCode\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12#\n\rname_katakana\x18\x04 \x01(\tR\x0cnameKatakana\x12#\n\rname_hiragana\x18\x05 \x01(\tR\x0cnameHiragana\x12#\n\rname_alphabet\x18\x06 \x01(\tR\x0cnameAlphabet"\x94\x01\n\nBankAssets\x12\x1b\n\tbank_code\x18\x01 \x01(\tR\x08\x62\x61nkCode\x12$\n\x0elogo_url_large\x18\x02 \x01(\tR\x0clogoUrlLarge\x12&\n\x0flogo_url_medium\x18\x03 \x01(\tR\rlogoUrlMedium\x12\x1b\n\tterms_url\x18\n \x01(\tR\x08termsUrl"\x97\x05\n\x05\x42uyer\x12P\n\x05\x65mail\x18\x01 \x01(\tB:\xbaH7\xba\x01\x34\n\x0bvalid_email\x12\x15must be a valid email\x1a\x0ethis.isEmail()R\x05\x65mail\x12\x1b\n\tforce_kyc\x18\x02 \x01(\x08R\x08\x66orceKyc\x12"\n\x04name\x18\x04 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18\x32H\x00R\x04name\x88\x01\x01\x12<\n\x12katakana_last_name\x18\x0b \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18\x32H\x01R\x10katakanaLastName\x88\x01\x01\x12>\n\x13katakana_first_name\x18\x0c \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18\x32H\x02R\x11katakanaFirstName\x88\x01\x01\x12(\n\x07\x61\x64\x64ress\x18\r \x01(\tB\t\xbaH\x06r\x04\x10\x05\x18\x64H\x03R\x07\x61\x64\x64ress\x88\x01\x01\x12\x41\n\nbirth_date\x18\x14 \x01(\tB\x1d\xbaH\x1ar\x18\x32\x16^(\\d{4}-\\d{2}-\\d{2})?$H\x04R\tbirthDate\x88\x01\x01\x12\x39\n\x06gender\x18\x15 \x01(\tB\x1c\xbaH\x19r\x17R\x06\x66\x65maleR\x04maleR\x07unknownH\x05R\x06gender\x88\x01\x01\x12:\n\x08metadata\x18\x1e \x03(\x0b\x32\x1e.common.v1.Buyer.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x07\n\x05_nameB\x15\n\x13_katakana_last_nameB\x16\n\x14_katakana_first_nameB\n\n\x08_addressB\r\n\x0b_birth_dateB\t\n\x07_gender"{\n\x03Kyc\x12\x1b\n\tpublic_id\x18\x01 \x01(\tR\x08publicId\x12)\n\x05state\x18\x02 \x01(\x0e\x32\x13.common.v1.KycStateR\x05state\x12,\n\x06result\x18\x03 \x01(\x0e\x32\x14.common.v1.KycResultR\x06result"\x81\x01\n\nDateFilter\x12,\n\x05range\x18\x01 \x01(\x0b\x32\x14.common.v1.DateRangeH\x00R\x05range\x12;\n\nexact_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\texactDateB\x08\n\x06\x66ilter"}\n\tDateRange\x12\x39\n\nstart_date\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartDate\x12\x35\n\x08\x65nd_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x65ndDate"^\n\x0eUserAgreements\x12L\n\x13jamm_user_agreement\x18\x02 \x01(\x0b\x32\x1c.common.v1.JammUserAgreementR\x11jammUserAgreement"\xb6\x01\n\x11JammUserAgreement\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12G\n\x0e\x61greement_name\x18\x02 \x01(\x0e\x32 .common.v1.JammUserAgreementNameR\ragreementName\x12\x37\n\tagreed_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08\x61greedAt"\xe6\x03\n\rTrustdockData\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1b\n\tpublic_id\x18\x02 \x01(\tR\x08publicId\x12\x14\n\x05state\x18\x03 \x01(\tR\x05state\x12\x16\n\x06result\x18\x04 \x01(\tR\x06result\x12;\n\x0b\x61\x63\x63\x65pted_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nacceptedAt\x12\x46\n\x11plans_selected_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0fplansSelectedAt\x12N\n\x15\x64ocument_submitted_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x13\x64ocumentSubmittedAt\x12;\n\x0bprepared_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\npreparedAt\x12;\n\x0bverified_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nverifiedAt\x12+\n\x07records\x18\n \x03(\x0b\x32\x11.common.v1.RecordR\x07records"\x8d\x01\n\x06Record\x12\x14\n\x05state\x18\x01 \x01(\tR\x05state\x12\x16\n\x06result\x18\x02 \x01(\tR\x06result\x12\x18\n\x07\x63ontent\x18\x03 \x01(\tR\x07\x63ontent\x12;\n\x0bverified_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nverifiedAt*X\n\x06Gender\x12\x16\n\x12GENDER_UNSPECIFIED\x10\x00\x12\x11\n\rGENDER_FEMALE\x10\x01\x12\x0f\n\x0bGENDER_MALE\x10\x02\x12\x12\n\x0eGENDER_UNKNOWN\x10\x03*\xa0\x01\n\x0c\x43ommonStatus\x12\x1d\n\x19\x43OMMON_STATUS_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43OMMON_STATUS_INITIAL\x10\x01\x12\x1b\n\x17\x43OMMON_STATUS_ACTIVATED\x10\x02\x12\x1d\n\x19\x43OMMON_STATUS_DEACTIVATED\x10\x03\x12\x1a\n\x16\x43OMMON_STATUS_BLOCKING\x10\x04*\xd8\x01\n\x0c\x43hargeStatus\x12\x1d\n\x19\x43HARGE_STATUS_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43HARGE_STATUS_SUCCESS\x10\x01\x12\x19\n\x15\x43HARGE_STATUS_FAILURE\x10\x02\x12\x1e\n\x1a\x43HARGE_STATUS_WAITING_EKYC\x10\x03\x12\x1a\n\x16\x43HARGE_STATUS_BLOCKING\x10\x04\x12\x1b\n\x17\x43HARGE_STATUS_CANCELLED\x10\x05\x12\x1a\n\x16\x43HARGE_STATUS_REFUNDED\x10\x06*\x9d\x01\n\x15JammUserAgreementName\x12(\n$JAMM_USER_AGREEMENT_NAME_UNSPECIFIED\x10\x00\x12+\n\'JAMM_USER_AGREEMENT_NAME_PRIVACY_POLICY\x10\x01\x12-\n)JAMM_USER_AGREEMENT_NAME_TERMS_OF_SERVICE\x10\x02*\xe1\x01\n\x08KycState\x12\x19\n\x15KYC_STATE_UNSPECIFIED\x10\x00\x12\x16\n\x12KYC_STATE_ACCEPTED\x10\x01\x12\x1c\n\x18KYC_STATE_PLANS_SELECTED\x10\x02\x12 \n\x1cKYC_STATE_DOCUMENT_SUBMITTED\x10\x03\x12\x19\n\x15KYC_STATE_IN_PROGRESS\x10\x04\x12\x16\n\x12KYC_STATE_VERIFIED\x10\x05\x12\x19\n\x15KYC_STATE_NOT_STARTED\x10\x06\x12\x14\n\x10KYC_STATE_DENIED\x10\x07*W\n\tKycResult\x12\x1a\n\x16KYC_RESULT_UNSPECIFIED\x10\x00\x12\x17\n\x13KYC_RESULT_APPROVED\x10\x01\x12\x15\n\x11KYC_RESULT_DENIED\x10\x02*\xb4\x01\n\x0cRefundStatus\x12\x1d\n\x19REFUND_STATUS_UNSPECIFIED\x10\x00\x12&\n"REFUND_STATUS_WAITING_CONFIRMATION\x10\x01\x12\x1b\n\x17REFUND_STATUS_CONFIRMED\x10\x02\x12\x18\n\x14REFUND_STATUS_FAILED\x10\x03\x12&\n"REFUND_STATUS_CANCELED_BY_MERCHANT\x10\x04*\xb1\x01\n\x0cRejectReason\x12\x1d\n\x19REJECT_REASON_UNSPECIFIED\x10\x00\x12)\n%REJECT_REASON_MERCHANT_REQUEST_DENIED\x10\x01\x12+\n\'REJECT_REASON_NEGATIVE_MERCHANT_BALANCE\x10\x02\x12*\n&REJECT_REASON_PAYMENT_REJECTED_BY_BANK\x10\x03\x42\x84\x01\n\rcom.common.v1B\x0bWebappProtoP\x01Z!api/proto/gen/common/v1;common_v1\xa2\x02\x03\x43XX\xaa\x02\tCommon.V1\xca\x02\tCommon\\V1\xe2\x02\x15\x43ommon\\V1\\GPBMetadata\xea\x02\nCommon::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "common.v1.webapp_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = (
        b"\n\rcom.common.v1B\013WebappProtoP\001Z!api/proto/gen/common/v1;common_v1\242\002\003CXX\252\002\tCommon.V1\312\002\tCommon\\V1\342\002\025Common\\V1\\GPBMetadata\352\002\nCommon::V1"
    )
    _globals["_BUYER_METADATAENTRY"]._loaded_options = None
    _globals["_BUYER_METADATAENTRY"]._serialized_options = b"8\001"
    _globals["_BUYER"].fields_by_name["email"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "email"
    ]._serialized_options = b"\272H7\272\0014\n\013valid_email\022\025must be a valid email\032\016this.isEmail()"
    _globals["_BUYER"].fields_by_name["name"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "name"
    ]._serialized_options = b"\272H\006r\004\020\001\0302"
    _globals["_BUYER"].fields_by_name["katakana_last_name"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "katakana_last_name"
    ]._serialized_options = b"\272H\006r\004\020\001\0302"
    _globals["_BUYER"].fields_by_name["katakana_first_name"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "katakana_first_name"
    ]._serialized_options = b"\272H\006r\004\020\001\0302"
    _globals["_BUYER"].fields_by_name["address"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "address"
    ]._serialized_options = b"\272H\006r\004\020\005\030d"
    _globals["_BUYER"].fields_by_name["birth_date"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "birth_date"
    ]._serialized_options = b"\272H\032r\0302\026^(\\d{4}-\\d{2}-\\d{2})?$"
    _globals["_BUYER"].fields_by_name["gender"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "gender"
    ]._serialized_options = b"\272H\031r\027R\006femaleR\004maleR\007unknown"
    _globals["_GENDER"]._serialized_start = 4188
    _globals["_GENDER"]._serialized_end = 4276
    _globals["_COMMONSTATUS"]._serialized_start = 4279
    _globals["_COMMONSTATUS"]._serialized_end = 4439
    _globals["_CHARGESTATUS"]._serialized_start = 4442
    _globals["_CHARGESTATUS"]._serialized_end = 4658
    _globals["_JAMMUSERAGREEMENTNAME"]._serialized_start = 4661
    _globals["_JAMMUSERAGREEMENTNAME"]._serialized_end = 4818
    _globals["_KYCSTATE"]._serialized_start = 4821
    _globals["_KYCSTATE"]._serialized_end = 5046
    _globals["_KYCRESULT"]._serialized_start = 5048
    _globals["_KYCRESULT"]._serialized_end = 5135
    _globals["_REFUNDSTATUS"]._serialized_start = 5138
    _globals["_REFUNDSTATUS"]._serialized_end = 5318
    _globals["_REJECTREASON"]._serialized_start = 5321
    _globals["_REJECTREASON"]._serialized_end = 5498
    _globals["_BANK"]._serialized_start = 100
    _globals["_BANK"]._serialized_end = 897
    _globals["_BANKQUOTA"]._serialized_start = 900
    _globals["_BANKQUOTA"]._serialized_end = 1671
    _globals["_BANKSCHEDULEDMAINTENANCEPERIOD"]._serialized_start = 1674
    _globals["_BANKSCHEDULEDMAINTENANCEPERIOD"]._serialized_end = 1863
    _globals["_BANKBRANCH"]._serialized_start = 1866
    _globals["_BANKBRANCH"]._serialized_end = 2071
    _globals["_BANKASSETS"]._serialized_start = 2074
    _globals["_BANKASSETS"]._serialized_end = 2222
    _globals["_BUYER"]._serialized_start = 2225
    _globals["_BUYER"]._serialized_end = 2888
    _globals["_BUYER_METADATAENTRY"]._serialized_start = 2735
    _globals["_BUYER_METADATAENTRY"]._serialized_end = 2794
    _globals["_KYC"]._serialized_start = 2890
    _globals["_KYC"]._serialized_end = 3013
    _globals["_DATEFILTER"]._serialized_start = 3016
    _globals["_DATEFILTER"]._serialized_end = 3145
    _globals["_DATERANGE"]._serialized_start = 3147
    _globals["_DATERANGE"]._serialized_end = 3272
    _globals["_USERAGREEMENTS"]._serialized_start = 3274
    _globals["_USERAGREEMENTS"]._serialized_end = 3368
    _globals["_JAMMUSERAGREEMENT"]._serialized_start = 3371
    _globals["_JAMMUSERAGREEMENT"]._serialized_end = 3553
    _globals["_TRUSTDOCKDATA"]._serialized_start = 3556
    _globals["_TRUSTDOCKDATA"]._serialized_end = 4042
    _globals["_RECORD"]._serialized_start = 4045
    _globals["_RECORD"]._serialized_end = 4186
# @@protoc_insertion_point(module_scope)
