# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: error/v1/error.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 30, 2, "", "error/v1/error.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14\x65rror/v1/error.proto\x12\x08\x65rror.v1*\x83\x06\n\tErrorType\x12\x1a\n\x16\x45RROR_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x45RROR_TYPE_AUTH_FAILED\x10\x01\x12\x1c\n\x18\x45RROR_TYPE_AUTH_REJECTED\x10\x02\x12&\n"ERROR_TYPE_ACCOUNT_CREATION_FAILED\x10\x65\x12*\n&ERROR_TYPE_ACCOUNT_MODIFICATION_FAILED\x10\x66\x12&\n"ERROR_TYPE_ACCOUNT_DELETION_FAILED\x10g\x12/\n+ERROR_TYPE_ACCOUNT_BANK_REGISTRATION_FAILED\x10h\x12\x1c\n\x17\x45RROR_TYPE_KYC_REJECTED\x10\xad\x02\x12+\n&ERROR_TYPE_NOTIFICATION_WEBHOOK_FAILED\x10\xf4\x03\x12)\n$ERROR_TYPE_NOTIFICATION_EMAIL_FAILED\x10\xf5\x03\x12\'\n"ERROR_TYPE_NOTIFICATION_SMS_FAILED\x10\xf6\x03\x12+\n&ERROR_TYPE_PAYMENT_GATEWAY_UNAVAILABLE\x10\xe8\x07\x12&\n!ERROR_TYPE_PAYMENT_GATEWAY_FAILED\x10\xe9\x07\x12)\n$ERROR_TYPE_PAYMENT_VALIDATION_FAILED\x10\xea\x07\x12%\n ERROR_TYPE_PAYMENT_CHARGE_FAILED\x10\xeb\x07\x12\'\n"ERROR_TYPE_PAYMENT_CHARGE_REJECTED\x10\xec\x07\x12)\n$ERROR_TYPE_PAYMENT_CHARGE_OVER_LIMIT\x10\xed\x07\x12\x33\n.ERROR_TYPE_PAYMENT_CHARGE_SUBSCRIPTION_EXPIRED\x10\xee\x07\x12$\n\x1f\x45RROR_TYPE_PAYMENT_LINK_EXPIRED\x10\xef\x07\x42\x80\x01\n\x0c\x63om.error.v1B\nErrorProtoP\x01Z!error/proto/gen/error/v1;error_v1\xa2\x02\x03\x45XX\xaa\x02\x08\x45rror.V1\xca\x02\tError_\\V1\xe2\x02\x15\x45rror_\\V1\\GPBMetadata\xea\x02\tError::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "error.v1.error_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = (
        b"\n\014com.error.v1B\nErrorProtoP\001Z!error/proto/gen/error/v1;error_v1\242\002\003EXX\252\002\010Error.V1\312\002\tError_\\V1\342\002\025Error_\\V1\\GPBMetadata\352\002\tError::V1"
    )
    _globals["_ERRORTYPE"]._serialized_start = 35
    _globals["_ERRORTYPE"]._serialized_end = 806
# @@protoc_insertion_point(module_scope)
