# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: api/v1/common.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 30, 2, "", "api/v1/common.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13\x61pi/v1/common.proto\x12\x06\x61pi.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xb6\x06\n\x05\x42uyer\x12P\n\x05\x65mail\x18\x01 \x01(\tB:\xbaH7\xba\x01\x34\n\x0bvalid_email\x12\x15must be a valid email\x1a\x0ethis.isEmail()R\x05\x65mail\x12\x1b\n\tforce_kyc\x18\x02 \x01(\x08R\x08\x66orceKyc\x12\x36\n\x05phone\x18\x03 \x01(\tB\x1b\xbaH\x18r\x16\x32\x11^0[789]0[0-9]{8}$\x98\x01\x0bH\x00R\x05phone\x88\x01\x01\x12"\n\x04name\x18\x04 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18\x32H\x01R\x04name\x88\x01\x01\x12<\n\x12katakana_last_name\x18\x0b \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18\x32H\x02R\x10katakanaLastName\x88\x01\x01\x12>\n\x13katakana_first_name\x18\x0c \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18\x32H\x03R\x11katakanaFirstName\x88\x01\x01\x12(\n\x07\x61\x64\x64ress\x18\r \x01(\tB\t\xbaH\x06r\x04\x10\x05\x18\x64H\x04R\x07\x61\x64\x64ress\x88\x01\x01\x12\x41\n\nbirth_date\x18\x14 \x01(\tB\x1d\xbaH\x1ar\x18\x32\x16^(\\d{4}-\\d{2}-\\d{2})?$H\x05R\tbirthDate\x88\x01\x01\x12\x39\n\x06gender\x18\x15 \x01(\tB\x1c\xbaH\x19r\x17R\x06\x66\x65maleR\x04maleR\x07unknownH\x06R\x06gender\x88\x01\x01\x12O\n\nexpires_at\x18\x16 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x0f\xbaH\x0c\xb2\x01\t@\x00J\x05\x08\x80\x9a\x9e\x01H\x07R\texpiresAt\x88\x01\x01\x12\x37\n\x08metadata\x18\x1e \x03(\x0b\x32\x1b.api.v1.Buyer.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x08\n\x06_phoneB\x07\n\x05_nameB\x15\n\x13_katakana_last_nameB\x16\n\x14_katakana_first_nameB\n\n\x08_addressB\r\n\x0b_birth_dateB\t\n\x07_genderB\r\n\x0b_expires_at"n\n\x10MerchantCustomer\x12,\n\x08\x63ustomer\x18\x01 \x01(\x0b\x32\x10.api.v1.CustomerR\x08\x63ustomer\x12,\n\x08merchant\x18\x02 \x01(\x0b\x32\x10.api.v1.MerchantR\x08merchant"\xc1\x02\n\x08\x43ustomer\x12\x1f\n\x02id\x18\x01 \x01(\tB\x0f\xbaH\x0cr\n2\x08^cus-.*$R\x02id\x12\x14\n\x05\x65mail\x18\x02 \x01(\tR\x05\x65mail\x12\x1c\n\tactivated\x18\x04 \x01(\x08R\tactivated\x12&\n\x06status\x18\x05 \x01(\x0b\x32\x0e.api.v1.StatusR\x06status\x12\x42\n\x10\x62\x61nk_information\x18\x06 \x01(\x0b\x32\x17.api.v1.BankInformationR\x0f\x62\x61nkInformation\x12\x39\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt"k\n\x06Status\x12<\n\x07payment\x18\x01 \x01(\x0e\x32".api.v1.PaymentAuthorizationStatusR\x07payment\x12#\n\x03kyc\x18\x02 \x01(\x0e\x32\x11.api.v1.KycStatusR\x03kyc"\xae\x01\n\x0f\x42\x61nkInformation\x12%\n\x0e\x61\x63\x63ount_number\x18\x01 \x01(\tR\raccountNumber\x12\x1b\n\tbank_name\x18\x02 \x01(\tR\x08\x62\x61nkName\x12\x1f\n\x0b\x62ranch_name\x18\x03 \x01(\tR\nbranchName\x12\x36\n\x0c\x64\x65posit_type\x18\x04 \x01(\x0e\x32\x13.api.v1.DepositTypeR\x0b\x64\x65positType"?\n\x08Merchant\x12\x1f\n\x02id\x18\x01 \x01(\tB\x0f\xbaH\x0cr\n2\x08^mer-.*$R\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name"\xd2\x01\n\x08\x43ontract\x12 \n\x02id\x18\x01 \x01(\tB\x10\xbaH\rr\x0b\x32\t^con-\\d+$R\x02id\x12.\n\x06status\x18\x02 \x01(\x0e\x32\x16.api.v1.ContractStatusR\x06status\x12\x39\n\ncreated_at\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt"S\n\nPagination\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\t\xbaH\x06\x1a\x04\x18\x64 \x00R\x08pageSize\x12\x1d\n\npage_token\x18\x02 \x01(\tR\tpageToken"\x8e\x06\n\x04\x42\x61nk\x12\x12\n\x04\x63ode\x18\x01 \x01(\tR\x04\x63ode\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12#\n\rname_katakana\x18\x03 \x01(\tR\x0cnameKatakana\x12#\n\rname_hiragana\x18\x04 \x01(\tR\x0cnameHiragana\x12#\n\rname_alphabet\x18\x05 \x01(\tR\x0cnameAlphabet\x12*\n\x06\x61ssets\x18\x0b \x01(\x0b\x32\x12.api.v1.BankAssetsR\x06\x61ssets\x12\'\n\x05quota\x18\x14 \x01(\x0b\x32\x11.api.v1.BankQuotaR\x05quota\x12#\n\ropening_hours\x18\x1e \x01(\tR\x0copeningHours\x12l\n\x1e\x62\x61nkpay_scheduled_maintenances\x18( \x03(\x0b\x32&.api.v1.BankScheduledMaintenancePeriodR\x1c\x62\x61nkpayScheduledMaintenances\x12\x66\n\x1b\x62\x61nk_scheduled_maintenances\x18) \x03(\x0b\x32&.api.v1.BankScheduledMaintenancePeriodR\x19\x62\x61nkScheduledMaintenances\x12v\n#registration_scheduled_maintenances\x18* \x03(\x0b\x32&.api.v1.BankScheduledMaintenancePeriodR!registrationScheduledMaintenances\x12+\n\x11\x62\x61nkpay_available\x18\x32 \x01(\x08R\x10\x62\x61nkpayAvailable\x12%\n\x0e\x62\x61nk_available\x18\x33 \x01(\x08R\rbankAvailable\x12\x35\n\x16registration_available\x18\x34 \x01(\x08R\x15registrationAvailable\x12\x1c\n\toperating\x18\x63 \x01(\x08R\toperating"\x83\x06\n\tBankQuota\x12X\n*offline_purchase_limit_per_charge_with_kyc\x18\x01 \x01(\x05R$offlinePurchaseLimitPerChargeWithKyc\x12^\n-offline_purchase_limit_per_charge_without_kyc\x18\x02 \x01(\x05R\'offlinePurchaseLimitPerChargeWithoutKyc\x12R\n\'offline_purchase_limit_per_day_with_kyc\x18\n \x01(\x05R!offlinePurchaseLimitPerDayWithKyc\x12X\n*offline_purchase_limit_per_day_without_kyc\x18\x0b \x01(\x05R$offlinePurchaseLimitPerDayWithoutKyc\x12\x62\n/subscription_purchase_limit_per_charge_with_kyc\x18\x14 \x01(\x05R)subscriptionPurchaseLimitPerChargeWithKyc\x12h\n2subscription_purchase_limit_per_charge_without_kyc\x18\x15 \x01(\x05R,subscriptionPurchaseLimitPerChargeWithoutKyc\x12\\\n,subscription_purchase_limit_per_day_with_kyc\x18\x1e \x01(\x05R&subscriptionPurchaseLimitPerDayWithKyc\x12\x62\n/subscription_purchase_limit_per_day_without_kyc\x18\x1f \x01(\x05R)subscriptionPurchaseLimitPerDayWithoutKyc"\xbd\x01\n\x1e\x42\x61nkScheduledMaintenancePeriod\x12\x1b\n\tbank_code\x18\x01 \x01(\tR\x08\x62\x61nkCode\x12 \n\x0cstart_at_jst\x18\x02 \x01(\tR\nstartAtJst\x12\x1c\n\nend_at_jst\x18\x03 \x01(\tR\x08\x65ndAtJst\x12 \n\x0cstart_at_utc\x18\x04 \x01(\tR\nstartAtUtc\x12\x1c\n\nend_at_utc\x18\x05 \x01(\tR\x08\x65ndAtUtc"\xcd\x01\n\nBankBranch\x12\x1b\n\tbank_code\x18\x01 \x01(\tR\x08\x62\x61nkCode\x12\x1f\n\x0b\x62ranch_code\x18\x02 \x01(\tR\nbranchCode\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12#\n\rname_katakana\x18\x04 \x01(\tR\x0cnameKatakana\x12#\n\rname_hiragana\x18\x05 \x01(\tR\x0cnameHiragana\x12#\n\rname_alphabet\x18\x06 \x01(\tR\x0cnameAlphabet"\x94\x01\n\nBankAssets\x12\x1b\n\tbank_code\x18\x01 \x01(\tR\x08\x62\x61nkCode\x12$\n\x0elogo_url_large\x18\x02 \x01(\tR\x0clogoUrlLarge\x12&\n\x0flogo_url_medium\x18\x03 \x01(\tR\rlogoUrlMedium\x12\x1b\n\tterms_url\x18\n \x01(\tR\x08termsUrl*`\n\x0b\x44\x65positType\x12\x1c\n\x18\x44\x45POSIT_TYPE_UNSPECIFIED\x10\x00\x12\x18\n\x14\x44\x45POSIT_TYPE_SAVINGS\x10\x01\x12\x19\n\x15\x44\x45POSIT_TYPE_CHECKING\x10\x02*\xa8\x01\n\x1aPaymentAuthorizationStatus\x12,\n(PAYMENT_AUTHORIZATION_STATUS_UNSPECIFIED\x10\x00\x12+\n\'PAYMENT_AUTHORIZATION_STATUS_AUTHORIZED\x10\x01\x12/\n+PAYMENT_AUTHORIZATION_STATUS_NOT_AUTHORIZED\x10\x02*\x8f\x01\n\tKycStatus\x12\x1a\n\x16KYC_STATUS_UNSPECIFIED\x10\x00\x12\x17\n\x13KYC_STATUS_APPROVED\x10\x01\x12\x1c\n\x18KYC_STATUS_NOT_SUBMITTED\x10\x02\x12\x18\n\x14KYC_STATUS_IN_REVIEW\x10\x03\x12\x15\n\x11KYC_STATUS_DENIED\x10\x04*\xae\x02\n\x0e\x43ontractStatus\x12\x1f\n\x1b\x43ONTRACT_STATUS_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x43ONTRACT_STATUS_INITIAL\x10\x01\x12\x1c\n\x18\x43ONTRACT_STATUS_APPROVED\x10\x02\x12\x1d\n\x19\x43ONTRACT_STATUS_ACTIVATED\x10\x03\x12 \n\x1c\x43ONTRACT_STATUS_WAITING_EKYC\x10\x04\x12\x1b\n\x17\x43ONTRACT_STATUS_EXPIRED\x10\x05\x12\x1f\n\x1b\x43ONTRACT_STATUS_DEACTIVATED\x10\x06\x12\x1d\n\x19\x43ONTRACT_STATUS_CANCELLED\x10\x07\x12"\n\x1e\x43ONTRACT_STATUS_PENDING_CHARGE\x10\x08\x42o\n\ncom.api.v1B\x0b\x43ommonProtoP\x01Z\x1b\x61pi/proto/gen/api/v1;api_v1\xa2\x02\x03\x41XX\xaa\x02\x06\x41pi.V1\xca\x02\x06\x41pi\\V1\xe2\x02\x12\x41pi\\V1\\GPBMetadata\xea\x02\x07\x41pi::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "api.v1.common_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = (
        b"\n\ncom.api.v1B\013CommonProtoP\001Z\033api/proto/gen/api/v1;api_v1\242\002\003AXX\252\002\006Api.V1\312\002\006Api\\V1\342\002\022Api\\V1\\GPBMetadata\352\002\007Api::V1"
    )
    _globals["_BUYER_METADATAENTRY"]._loaded_options = None
    _globals["_BUYER_METADATAENTRY"]._serialized_options = b"8\001"
    _globals["_BUYER"].fields_by_name["email"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "email"
    ]._serialized_options = b"\272H7\272\0014\n\013valid_email\022\025must be a valid email\032\016this.isEmail()"
    _globals["_BUYER"].fields_by_name["phone"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "phone"
    ]._serialized_options = b"\272H\030r\0262\021^0[789]0[0-9]{8}$\230\001\013"
    _globals["_BUYER"].fields_by_name["name"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "name"
    ]._serialized_options = b"\272H\006r\004\020\001\0302"
    _globals["_BUYER"].fields_by_name["katakana_last_name"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "katakana_last_name"
    ]._serialized_options = b"\272H\006r\004\020\001\0302"
    _globals["_BUYER"].fields_by_name["katakana_first_name"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "katakana_first_name"
    ]._serialized_options = b"\272H\006r\004\020\001\0302"
    _globals["_BUYER"].fields_by_name["address"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "address"
    ]._serialized_options = b"\272H\006r\004\020\005\030d"
    _globals["_BUYER"].fields_by_name["birth_date"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "birth_date"
    ]._serialized_options = b"\272H\032r\0302\026^(\\d{4}-\\d{2}-\\d{2})?$"
    _globals["_BUYER"].fields_by_name["gender"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "gender"
    ]._serialized_options = b"\272H\031r\027R\006femaleR\004maleR\007unknown"
    _globals["_BUYER"].fields_by_name["expires_at"]._loaded_options = None
    _globals["_BUYER"].fields_by_name[
        "expires_at"
    ]._serialized_options = b"\272H\014\262\001\t@\000J\005\010\200\232\236\001"
    _globals["_CUSTOMER"].fields_by_name["id"]._loaded_options = None
    _globals["_CUSTOMER"].fields_by_name[
        "id"
    ]._serialized_options = b"\272H\014r\n2\010^cus-.*$"
    _globals["_MERCHANT"].fields_by_name["id"]._loaded_options = None
    _globals["_MERCHANT"].fields_by_name[
        "id"
    ]._serialized_options = b"\272H\014r\n2\010^mer-.*$"
    _globals["_CONTRACT"].fields_by_name["id"]._loaded_options = None
    _globals["_CONTRACT"].fields_by_name[
        "id"
    ]._serialized_options = b"\272H\rr\0132\t^con-\\d+$"
    _globals["_PAGINATION"].fields_by_name["page_size"]._loaded_options = None
    _globals["_PAGINATION"].fields_by_name[
        "page_size"
    ]._serialized_options = b"\272H\006\032\004\030d \000"
    _globals["_DEPOSITTYPE"]._serialized_start = 4113
    _globals["_DEPOSITTYPE"]._serialized_end = 4209
    _globals["_PAYMENTAUTHORIZATIONSTATUS"]._serialized_start = 4212
    _globals["_PAYMENTAUTHORIZATIONSTATUS"]._serialized_end = 4380
    _globals["_KYCSTATUS"]._serialized_start = 4383
    _globals["_KYCSTATUS"]._serialized_end = 4526
    _globals["_CONTRACTSTATUS"]._serialized_start = 4529
    _globals["_CONTRACTSTATUS"]._serialized_end = 4831
    _globals["_BUYER"]._serialized_start = 94
    _globals["_BUYER"]._serialized_end = 916
    _globals["_BUYER_METADATAENTRY"]._serialized_start = 738
    _globals["_BUYER_METADATAENTRY"]._serialized_end = 797
    _globals["_MERCHANTCUSTOMER"]._serialized_start = 918
    _globals["_MERCHANTCUSTOMER"]._serialized_end = 1028
    _globals["_CUSTOMER"]._serialized_start = 1031
    _globals["_CUSTOMER"]._serialized_end = 1352
    _globals["_STATUS"]._serialized_start = 1354
    _globals["_STATUS"]._serialized_end = 1461
    _globals["_BANKINFORMATION"]._serialized_start = 1464
    _globals["_BANKINFORMATION"]._serialized_end = 1638
    _globals["_MERCHANT"]._serialized_start = 1640
    _globals["_MERCHANT"]._serialized_end = 1703
    _globals["_CONTRACT"]._serialized_start = 1706
    _globals["_CONTRACT"]._serialized_end = 1916
    _globals["_PAGINATION"]._serialized_start = 1918
    _globals["_PAGINATION"]._serialized_end = 2001
    _globals["_BANK"]._serialized_start = 2004
    _globals["_BANK"]._serialized_end = 2786
    _globals["_BANKQUOTA"]._serialized_start = 2789
    _globals["_BANKQUOTA"]._serialized_end = 3560
    _globals["_BANKSCHEDULEDMAINTENANCEPERIOD"]._serialized_start = 3563
    _globals["_BANKSCHEDULEDMAINTENANCEPERIOD"]._serialized_end = 3752
    _globals["_BANKBRANCH"]._serialized_start = 3755
    _globals["_BANKBRANCH"]._serialized_end = 3960
    _globals["_BANKASSETS"]._serialized_start = 3963
    _globals["_BANKASSETS"]._serialized_end = 4111
# @@protoc_insertion_point(module_scope)
