# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: api/v1/merchant_webhooks.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 30, 2, "", "api/v1/merchant_webhooks.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1e\x61pi/v1/merchant_webhooks.proto\x12\x06\x61pi.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\x10\n\x0eMessageRequest"\xbb\x02\n\x0fMessageResponse\x12X\n\x18merchant_webhook_message\x18\x01 \x01(\x0b\x32\x1e.api.v1.MerchantWebhookMessageR\x16merchantWebhookMessage\x12<\n\x0e\x63harge_message\x18\x02 \x01(\x0b\x32\x15.api.v1.ChargeMessageR\rchargeMessage\x12\x42\n\x10\x63ontract_message\x18\x03 \x01(\x0b\x32\x17.api.v1.ContractMessageR\x0f\x63ontractMessage\x12L\n\x14user_account_message\x18\x04 \x01(\x0b\x32\x1a.api.v1.UserAccountMessageR\x12userAccountMessage"\xe4\x01\n\x16MerchantWebhookMessage\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1c\n\tsignature\x18\x02 \x01(\tR\tsignature\x12\x30\n\nevent_type\x18\x04 \x01(\x0e\x32\x11.api.v1.EventTypeR\teventType\x12.\n\x07\x63ontent\x18\x05 \x01(\x0b\x32\x14.google.protobuf.AnyR\x07\x63ontent\x12:\n\ncreated_at\x18\xe7\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt"\xc7\x05\n\rChargeMessage\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12+\n\x08\x63ustomer\x18\x02 \x01(\tB\x0f\xbaH\x0cr\n2\x08^cus-.*$R\x08\x63ustomer\x12\x34\n\x06status\x18\x03 \x01(\x0e\x32\x1c.api.v1.ChargeMessage.StatusR\x06status\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\x12#\n\rmerchant_name\x18\x05 \x01(\tR\x0cmerchantName\x12%\n\x0einitial_amount\x18\x06 \x01(\x05R\rinitialAmount\x12\x1a\n\x08\x64iscount\x18\x07 \x01(\x05R\x08\x64iscount\x12!\n\x0c\x66inal_amount\x18\x08 \x01(\x05R\x0b\x66inalAmount\x12,\n\x0f\x61mount_refunded\x18\t \x01(\x05H\x00R\x0e\x61mountRefunded\x88\x01\x01\x12\x1a\n\x08\x63urrency\x18\n \x01(\tR\x08\x63urrency\x12&\n\x0cprocessed_at\x18\x0b \x01(\tH\x01R\x0bprocessedAt\x88\x01\x01\x12\x1d\n\ncreated_at\x18\r \x01(\tR\tcreatedAt\x12\x1d\n\nupdated_at\x18\x0e \x01(\tR\tupdatedAt\x12(\n\x05\x65rror\x18\x14 \x01(\x0b\x32\r.api.v1.ErrorH\x02R\x05\x65rror\x88\x01\x01"\x8c\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x12\n\x0eSTATUS_SUCCESS\x10\x01\x12\x12\n\x0eSTATUS_FAILURE\x10\x02\x12\x17\n\x13STATUS_WAITING_EKYC\x10\x03\x12\x13\n\x0fSTATUS_BLOCKING\x10\x04\x12\x14\n\x10STATUS_CANCELLED\x10\x05\x42\x12\n\x10_amount_refundedB\x0f\n\r_processed_atB\x08\n\x06_error"\xa5\x01\n\x0f\x43ontractMessage\x12+\n\x08\x63ustomer\x18\x01 \x01(\tB\x0f\xbaH\x0cr\n2\x08^cus-.*$R\x08\x63ustomer\x12\x1d\n\ncreated_at\x18\x02 \x01(\tR\tcreatedAt\x12!\n\x0c\x61\x63tivated_at\x18\x03 \x01(\tR\x0b\x61\x63tivatedAt\x12#\n\rmerchant_name\x18\x04 \x01(\tR\x0cmerchantName"\x9b\x01\n\x12UserAccountMessage\x12+\n\x08\x63ustomer\x18\x01 \x01(\tB\x0f\xbaH\x0cr\n2\x08^cus-.*$R\x08\x63ustomer\x12\x14\n\x05\x65mail\x18\x02 \x01(\tR\x05\x65mail\x12\x1d\n\ndeleted_at\x18\x03 \x01(\tR\tdeletedAt\x12#\n\rmerchant_name\x18\x04 \x01(\tR\x0cmerchantName"5\n\x05\x45rror\x12\x12\n\x04\x63ode\x18\x01 \x01(\tR\x04\x63ode\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message*\x9e\x02\n\tEventType\x12\x1a\n\x16\x45VENT_TYPE_UNSPECIFIED\x10\x00\x12\x1d\n\x19\x45VENT_TYPE_CHARGE_CREATED\x10\x03\x12\x1d\n\x19\x45VENT_TYPE_CHARGE_UPDATED\x10\x04\x12\x1d\n\x19\x45VENT_TYPE_CHARGE_SUCCESS\x10\x05\x12\x1a\n\x16\x45VENT_TYPE_CHARGE_FAIL\x10\x06\x12\x1c\n\x18\x45VENT_TYPE_CHARGE_CANCEL\x10\x07\x12!\n\x1d\x45VENT_TYPE_CONTRACT_ACTIVATED\x10\x14\x12#\n\x1f\x45VENT_TYPE_USER_ACCOUNT_DELETED\x10\x1e\x12\x16\n\x12\x45VENT_TYPE_TESTING\x10\x63\x32\x62\n\x0eWebhookService\x12P\n\x07Message\x12\x16.api.v1.MessageRequest\x1a\x17.api.v1.MessageResponse"\x14\x82\xd3\xe4\x93\x02\x0e"\t/webhooks:\x01*By\n\ncom.api.v1B\x15MerchantWebhooksProtoP\x01Z\x1b\x61pi/proto/gen/api/v1;api_v1\xa2\x02\x03\x41XX\xaa\x02\x06\x41pi.V1\xca\x02\x06\x41pi\\V1\xe2\x02\x12\x41pi\\V1\\GPBMetadata\xea\x02\x07\x41pi::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "api.v1.merchant_webhooks_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = (
        b"\n\ncom.api.v1B\025MerchantWebhooksProtoP\001Z\033api/proto/gen/api/v1;api_v1\242\002\003AXX\252\002\006Api.V1\312\002\006Api\\V1\342\002\022Api\\V1\\GPBMetadata\352\002\007Api::V1"
    )
    _globals["_CHARGEMESSAGE"].fields_by_name["customer"]._loaded_options = None
    _globals["_CHARGEMESSAGE"].fields_by_name[
        "customer"
    ]._serialized_options = b"\272H\014r\n2\010^cus-.*$"
    _globals["_CONTRACTMESSAGE"].fields_by_name["customer"]._loaded_options = None
    _globals["_CONTRACTMESSAGE"].fields_by_name[
        "customer"
    ]._serialized_options = b"\272H\014r\n2\010^cus-.*$"
    _globals["_USERACCOUNTMESSAGE"].fields_by_name["customer"]._loaded_options = None
    _globals["_USERACCOUNTMESSAGE"].fields_by_name[
        "customer"
    ]._serialized_options = b"\272H\014r\n2\010^cus-.*$"
    _globals["_WEBHOOKSERVICE"].methods_by_name["Message"]._loaded_options = None
    _globals["_WEBHOOKSERVICE"].methods_by_name[
        "Message"
    ]._serialized_options = b'\202\323\344\223\002\016"\t/webhooks:\001*'
    _globals["_EVENTTYPE"]._serialized_start = 1824
    _globals["_EVENTTYPE"]._serialized_end = 2110
    _globals["_MESSAGEREQUEST"]._serialized_start = 161
    _globals["_MESSAGEREQUEST"]._serialized_end = 177
    _globals["_MESSAGERESPONSE"]._serialized_start = 180
    _globals["_MESSAGERESPONSE"]._serialized_end = 495
    _globals["_MERCHANTWEBHOOKMESSAGE"]._serialized_start = 498
    _globals["_MERCHANTWEBHOOKMESSAGE"]._serialized_end = 726
    _globals["_CHARGEMESSAGE"]._serialized_start = 729
    _globals["_CHARGEMESSAGE"]._serialized_end = 1440
    _globals["_CHARGEMESSAGE_STATUS"]._serialized_start = 1253
    _globals["_CHARGEMESSAGE_STATUS"]._serialized_end = 1393
    _globals["_CONTRACTMESSAGE"]._serialized_start = 1443
    _globals["_CONTRACTMESSAGE"]._serialized_end = 1608
    _globals["_USERACCOUNTMESSAGE"]._serialized_start = 1611
    _globals["_USERACCOUNTMESSAGE"]._serialized_end = 1766
    _globals["_ERROR"]._serialized_start = 1768
    _globals["_ERROR"]._serialized_end = 1821
    _globals["_WEBHOOKSERVICE"]._serialized_start = 2112
    _globals["_WEBHOOKSERVICE"]._serialized_end = 2210
# @@protoc_insertion_point(module_scope)
